==> patch-2.5.3.15.zip: app/language/en/syncPms.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'Policy Management',
	'backupPolicy' => 'Sync Policy',
	'schedule' => 'Schedule',
	'schedules' => 'Schedules',
	'filters' => 'Filters',
	'userPolicy' => 'User Policy Mapping',
	'multipleUserPolicy' => 'Multiple Users Policy Mapping',
	'networkThrottling' => 'Network Throttling',
	'create' => 'Create',
	'edit' => 'Edit',
	'list' => 'List',
	'polices' => 'EFSS Polices',
	'policy' => 'EFSS Policy',
	'change_user_policy' => 'Change User Policy',
	'policy_mapping' => 'EFSS Policy Mapping',
	'bluvault' => 'Paracloud',
	'blukrypt' => 'Blukrypt',
	'assign_policy_for_users_in_bulk' => 'Assign Policy for Users in bulk',
	'assign_policy' => 'Assign Policy',
	'cloudCredentials' => 'Cloud Credentials',
	'bludrivepolices' => 'BluDrive Policies',

	// Common For all Methods
	'profileDisplay' => 'Account Details',
	'myDevices' => 'My Devices',
	'scheduleSaved' => 'Schedule updated successfully.',
	'filterSaved' 	=> 'Filter updated successfully.',
	'policySaved' 	=> 'Policy updated successfully.',
	'bluVaultNotInstalled' 	=> 'Please check if the Paracloud software has been installed on the specified machine.',
	'bluKryptNotInstalled' 	=> 'Please check if the BluKrypt software has been installed on the specified machine.',
	'421'       	=> 'Authentication token has <b>expired</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'4061'          => 'Policy with same name already exists',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'cannotBlock'   => 'You cannot block <b>yourself</b>.  Please contact your Administrator for assistance.',
	'cannotDelete'  => 'You cannot delete <b>yourself</b>.   Please contact your Administrator for assistance.',
	'userBlocked'   => 'The selected user has been blocked successfully.',
	'userDeleted'   => 'The selected user has been deleted successfully.',
	'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
	'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
	'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
	'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.',
	'alreadyMapped' => 'Policy already mapped to users',
	'policyBlocked'   => ' has been blocked successfully.',
	'noPolicy'      => 'No Policies Found',
	'alreadyMappedDelegatedAdmin' => 'This is the only policy managed by one of delegated admin.',
);

==> patch-2.5.3.18_3.zip: app/language/en/syncPms.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'Policy Management',
	'backupPolicy' => 'Sync Policy',
	'schedule' => 'Schedule',
	'schedules' => 'Schedules',
	'filters' => 'Filters',
	'userPolicy' => 'User Policy Mapping',
	'multipleUserPolicy' => 'Multiple Users Policy Mapping',
	'networkThrottling' => 'Network Throttling',
	'create' => 'Create',
	'edit' => 'Edit',
	'list' => 'List',
	'polices' => 'EFSS Policies',
	'policy' => 'EFSS Policy',
	'change_user_policy' => 'Change User Policy',
	'policy_mapping' => 'EFSS Policy Mapping',
	'bluvault' => 'Paracloud',
	'blukrypt' => 'Blukrypt',
	'assign_policy_for_users_in_bulk' => 'Assign Policy for Users in bulk',
	'assign_policy' => 'Assign Policy',
	'cloudCredentials' => 'Cloud Credentials',
	'bludrivepolices' => 'BluDrive Policies',

	// Common For all Methods
	'profileDisplay' => 'Account Details',
	'myDevices' => 'My Devices',
	'scheduleSaved' => 'Schedule updated successfully.',
	'filterSaved' 	=> 'Filter updated successfully.',
	'policySaved' 	=> 'Policy updated successfully.',
	'bluVaultNotInstalled' 	=> 'Please check if the Paracloud software has been installed on the specified machine.',
	'bluKryptNotInstalled' 	=> 'Please check if the BluKrypt software has been installed on the specified machine.',
	'421'       	=> 'Authentication token has <b>expired</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'4061'          => 'Policy with same name already exists',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'cannotBlock'   => 'You cannot block <b>yourself</b>.  Please contact your Administrator for assistance.',
	'cannotDelete'  => 'You cannot delete <b>yourself</b>.   Please contact your Administrator for assistance.',
	'userBlocked'   => 'The selected user has been blocked successfully.',
	'userDeleted'   => 'The selected user has been deleted successfully.',
	'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
	'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
	'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
	'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.',
	'alreadyMapped' => 'Policy already mapped to users',
	'policyBlocked'   => ' has been blocked successfully.',
	'noPolicy'      => 'No Policies Found',
	'alreadyMappedDelegatedAdmin' => 'This is the only policy managed by one of delegated admin.',
);
